=====
Usage
=====

Use pipecash in the command line::


        Usage: pipecash [OPTIONS]

        Console script for pipecash.

        Options:
        --version                       Show the version and exit.
        -s, --scenarioPath FILE         Path to the scenario JSON file.  [required]
        --secretsPath FILE              Path to the screts JSON file.
        --logLevel [NOTSET|DEBUG|INFO|WARN|ERROR|FATAL]
                                        log level for the main log
        --agentLogLevel [NOTSET|DEBUG|INFO|WARN|ERROR|FATAL]
                                        log level for the agent log
        --walletLogLevel [NOTSET|DEBUG|INFO|WARN|ERROR|FATAL]
                                        log level for the wallet log
        --help                          Show this message and exit.
